@@ -1,43 +1,29 @@
-/***************************************************************************
-             filter_lnotes.cxx  -  Lotus Notes Structured Text mail import
-                             -------------------
-    begin                : Wed Feb 16, 2005
-    copyright            : (C) 2005 by Robert Rockers
-    email                : kconfigure@rockerssoft.com
- ***************************************************************************/
+/*
+  filterlnotes.cpp  -  Lotus Notes Structured Text mail import
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+  SPDX-FileCopyrightText: 2005 Robert Rockers <kconfigure@rockerssoft.com>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-#include <KLocalizedString>
-#include <qfiledialog.h>
-#include <QTemporaryFile>
-#include "mailimporter_debug.h"
-#include <QFileInfo>
 
 #include "filterlnotes.h"
+
+#include <KLocalizedString>
+
+#include <QFileDialog>
+#include <QTemporaryFile>
+
 using namespace MailImporter;
 class MailImporter::FilterLNotesPrivate
 {
 public:
-    FilterLNotesPrivate()
-        : currentFile(1)
-        , totalFiles(0)
-    {
-    }
-
     /** the working directory */
     QDir dir;
     /** which file (of d->totalFiles) is now in the work? */
-    int currentFile;
+    int currentFile = 1;
     /** total number of files that get imported */
-    int totalFiles;
+    int totalFiles = 0;
 };
 
 /** Default constructor. */
@@ -111,7 +97,7 @@ void FilterLNotes::ImportLNotes(const QString &file)
         char ch = 0;
         int state = 0;
         int n = 0;
-        QTemporaryFile *tempfile = 0;
+        QTemporaryFile *tempfile = nullptr;
 
         // Get folder name
         QFileInfo filenameInfo(file);
@@ -134,16 +120,17 @@ void FilterLNotes::ImportLNotes(const QString &file)
                 tempfile->setAutoRemove(false);
                 tempfile->open();
                 // fall through
-#if QT_VERSION >= QT_VERSION_CHECK(5, 8, 0)
                 Q_FALLTHROUGH();
-#endif
             // inside a message state
             case 1:
                 if (ch == 0x0c) {
                     // close file, send it
                     tempfile->close();
 
-                    importMessage(folder, tempfile->fileName(), filterInfo()->removeDupMessage());
+
+                    if (!importMessage(folder, tempfile->fileName(), filterInfo()->removeDupMessage())) {
+                        filterInfo()->addErrorLogEntry(i18n("Could not import %1", tempfile->fileName()));
+                    }
 
                     tempfile->setAutoRemove(true);
                     state = 0;
@@ -172,7 +159,9 @@ void FilterLNotes::ImportLNotes(const QString &file)
         if (state != 0) {
             Q_ASSERT(tempfile);
 
-            importMessage(folder, tempfile->fileName(), filterInfo()->removeDupMessage());
+            if (!importMessage(folder, tempfile->fileName(), filterInfo()->removeDupMessage())) {
+                filterInfo()->addErrorLogEntry(i18n("Could not import %1", tempfile->fileName()));
+            }
         }
         if (tempfile) {
             tempfile->setAutoRemove(true);
