@@ -1,28 +1,22 @@
-/***************************************************************************
-                          filter_oe.cxx  -  Outlook Express mail import
-                             -------------------
-    begin                : Sat Feb 1 2003
-    copyright            : (C) 2003 by Laurence Anderson <l.d.anderson@warwick.ac.uk>
-                           (C) 2005 by Danny Kukawka <danny.Kukawka@web.de>
- ***************************************************************************/
+/*
+  filter_oe.cpp  -  Outlook Express mail import
+
+  SPDX-FileCopyrightText: 2003 Laurence Anderson <l.d.anderson@warwick.ac.uk>
+  SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.Kukawka@web.de>
+
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
 // This filter was created by looking at libdbx  &liboe
 
-#include <KLocalizedString>
-#include <QTemporaryFile>
-#include "mailimporter_debug.h"
-#include <QFileDialog>
-
 #include "filteroe.h"
+#include "mailimporter_debug.h"
+
+#include <QFileDialog>
+#include <KLocalizedString>
+
+#include <QTemporaryFile>
 
 #define OE4_SIG_1 0x36464d4a
 #define OE4_SIG_2 0x00010003
@@ -172,7 +166,6 @@ void FilterOE::importMailBox(const QString &fileName)
             }
         }
     }
-    // filterInfo()->addInfoLogEntry(i18n("File %1 does not seem to be an Outlook Express mailbox").arg("../" + _nameOfFile));
 }
 
 /* ------------------- MBX support ------------------- */
@@ -210,7 +203,9 @@ void FilterOE::mbxImport(QDataStream &ds)
             }
         } while (!ds.atEnd());
         tmp.flush();
-        importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage());
+        if (!importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage())) {
+            filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+        }
 
         if (filterInfo()->shouldTerminate()) {
             return;
@@ -371,7 +366,9 @@ void FilterOE::dbxReadEmail(QDataStream &ds, int filePos)
     tmp.flush();
 
     if (!_break) {
-        importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage());
+        if (!importMessage(folderName, tmp.fileName(), filterInfo()->removeDupMessage())) {
+            filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+        }
 
         currentEmail++;
         int currentPercentage = (int)(((float)currentEmail / totalEmails) * 100);
